==> igniteui-react-core-16.6.4.tgz: package/ES5/SortDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
var SortDescription = /** @class */ (function (_super) {
    tslib_1.__extends(SortDescription, _super);
    function SortDescription(a) {
        var _rest = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            _rest[_i - 1] = arguments[_i];
        }
        var _this = _super.call(this) || this;
        _this.a = false;
        _this.f = null;
        _this.c = 0;
        a = (a == void 0) ? 0 : a;
        switch (a) {
            case 0:
                {
                    var c = _rest[0];
                    _this.propertyName = c;
                }
                break;
            case 1:
                {
                    var c = _rest[0];
                    var d = _rest[1];
                    _this.propertyName = c;
                    _this.direction = d;
                }
                break;
        }
        return _this;
    }
    Object.defineProperty(SortDescription.prototype, "propertyName", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SortDescription.prototype, "direction", {
        get: function () {
            return this.c;
        },
        set: function (a) {
            this.c = a;
        },
        enumerable: true,
        configurable: true
    });
    SortDescription.prototype.equals = function (a) {
        var b = a;
        if (b == null) {
            return _super.prototype.equals.call(this, a);
        }
        return b.propertyName == this.propertyName && b.direction == this.direction;
    };
    SortDescription.prototype.getHashCode = function () {
        return Base.getHashCodeStatic(this.propertyName) * 17 + this.direction;
    };
    SortDescription.prototype.h = function () {
        this.a = true;
    };
    SortDescription.$t = markType(SortDescription, 'SortDescription');
    return SortDescription;
}(Base));
export { SortDescription };

==> igniteui-react-core-16.11.4.tgz: package/ES5/SortDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, markType } from "./type";
/**
 * @hidden
 */
var SortDescription = /** @class */ (function (_super) {
    tslib_1.__extends(SortDescription, _super);
    function SortDescription() {
        var _this = _super.call(this) || this;
        _this.b = false;
        _this.g = null;
        _this.d = 0;
        return _this;
    }
    Object.defineProperty(SortDescription.prototype, "propertyName", {
        get: function () {
            return this.g;
        },
        set: function (a) {
            this.g = a;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(SortDescription.prototype, "direction", {
        get: function () {
            return this.d;
        },
        set: function (a) {
            this.d = a;
        },
        enumerable: true,
        configurable: true
    });
    SortDescription.prototype.equals = function (a) {
        var b = a;
        if (b == null) {
            return _super.prototype.equals.call(this, a);
        }
        return b.propertyName == this.propertyName && b.direction == this.direction;
    };
    SortDescription.prototype.getHashCode = function () {
        return Base.getHashCodeStatic(this.propertyName) * 17 + this.direction;
    };
    SortDescription.prototype.i = function () {
        this.b = true;
    };
    SortDescription.create = function (a, b) {
        var c = new SortDescription();
        c.propertyName = a;
        c.direction = b;
        return c;
    };
    SortDescription.$t = markType(SortDescription, 'SortDescription');
    return SortDescription;
}(Base));
export { SortDescription };
